package com.zbf.system.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.zbf.system.domain.TPanDetail;

import java.util.List;

/**
 * 盘点明细Mapper接口
 *
 * @author wgs
 * @date 2024-06-20
 */
public interface TPanDetailMapper extends BaseMapper<TPanDetail> //修改
{
    /**
     * 查询盘点明细
     *
     * @param id 盘点明细主键
     * @return 盘点明细
     */
    public TPanDetail selectTPanDetailById(Long id);

    /**
     * 查询盘点明细列表
     *
     * @param tPanDetail 盘点明细
     * @return 盘点明细集合
     */
    public List<TPanDetail> selectTPanDetailList(TPanDetail tPanDetail);

    /**
     * 新增盘点明细
     *
     * @param tPanDetail 盘点明细
     * @return 结果
     */
    public int insertTPanDetail(TPanDetail tPanDetail);

    /**
     * 修改盘点明细
     *
     * @param tPanDetail 盘点明细
     * @return 结果
     */
    public int updateTPanDetail(TPanDetail tPanDetail);

    /**
     * 删除盘点明细
     *
     * @param id 盘点明细主键
     * @return 结果
     */
    public int deleteTPanDetailById(String id);

    /**
     * 批量删除盘点明细
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTPanDetailByIds(Long[] ids);

    /**
     * 批量启用盘点明细
     *
     * @param ids 需要启用的数据主键集合
     * @return 结果
     */
    public int enableTPanDetailByIds(Long[] ids);

    /**
     * 批量禁用盘点明细
     *
     * @param ids 需要禁用的数据主键集合
     * @return 结果
     */
    public int disabledTPanDetailByIds(Long[] ids);

    /**批量插入盘点明细 */
    public int batchInsertTPanDetail(List<TPanDetail> tPanDetailList);

    TPanDetail getList(String stockId);
}
